@@ -40,15 +40,18 @@ OverallDIF_ <- function(beta1, beta2, acov1, acov2)
 #' @return An object of class \code{DIF_stats} holding statistics for
 #' overall-DIF and a matrix of statistics for DIF in the relative position of
 #' item-category parameters in the beta-parameterization where they represent 
-#' locations on the ability scale where adjacent categories are equally likely.
+#' locations on the ability scale where adjacent categories are equally likely. 
+#' If there is DIF, the function `plot` can be used to produce an image of the pairwise DIF statistics.
 #' @details 
 #' Tests for equality of relative item/category difficulties across groups.
-#' Supplements the confirmatory approach of the profile plot
+#' Supplements the confirmatory approach of the profile plot.
 #' 
 #' @references 
 #' Bechger, T. M. and Maris, G (2015); A Statistical Test for Differential Item Pair Functioning. 
 #' Psychometrika. Vol. 80, no. 2, 317-340.
 #' 
+#' @seealso A plot of the result is produced by the function \code{\link{plot.DIF_stats}}
+#' 
 #' @examples
 #' db = start_new_project(verbAggrRules, ":memory:", person_properties=list(gender='unknown'))
 #' add_booklet(db, verbAggrData, "agg")
@@ -78,28 +81,25 @@ DIF = function(dataSrc, person_property, predicate=NULL)
   if(nlevels(respData$x[[person_property]]) != 2)
     stop('The person_property needs to have two unique values in your data to calculate DIF')
   
+  
+  problems = unequal_categories(respData, person_property)
+
+  if(length(problems)>0)
+  {
+    message('items removed:')
+    print(as.character(problems))
+    warning('Some items do not have the same score categories over both person_properties and\n',
+            'have been removed from the analysis',call.=FALSE)
+    
+    respData = respData %>%
+      anti_join(tibble(item_id=problems), by='item_id', .recompute_sumscores = TRUE)
+  }
+  
 
   ## 2. Estimate models with fit_enorm using CML
   models = by(respData, person_property, fit_enorm)
   
-  ## check if score categories match, otherwise remove,removal after analysis because it's (or should be) rare
-  problems = dplyr::union(
-    anti_join(models[[1]]$inputs$ssIS[,c('item_id','item_score')], models[[2]]$inputs$ssIS, by=c('item_id','item_score')),
-    anti_join(models[[2]]$inputs$ssIS[,c('item_id','item_score')], models[[1]]$inputs$ssIS, by=c('item_id','item_score'))) %>% 
-    distinct(.data$item_id)
-  
-  if(NROW(problems)>0)
-  {
-    warning('The following items do not have the same score categories over both person_properties and\n',
-            'have been removed from the analysis',call.=FALSE)
-    print(as.character(problems$item_id))
-    
-    respData = respData %>%
-      anti_join(problems, by='item_id', .recompute_sumscores = TRUE)
-    
-    models = by(respData, person_property, fit_enorm)
-  }
-  
+
   
   ## 4. Call overallDIF_ and PairDIF_
   DIF_stats = OverallDIF_ (models[[1]]$est$beta, models[[2]]$est$beta, 
@@ -114,6 +114,9 @@ DIF = function(dataSrc, person_property, predicate=NULL)
     arrange(.data$item_id, .data$item_score) %>%
     mutate(item_id=as.character(.data$item_id))
   
+  
+  if(show_progress()) pg_close()
+  
   ## 5. Report D and DIF_stats and inputs
   ou = list(DIF_overall = DIF_stats, DIF_pair = DIF_mats$D, Delta_R = DIF_mats$Delta_R, 
             group_labels = names(models), items = items)
@@ -134,17 +137,22 @@ print.DIF_stats <- function(x, ...)
 }
 
 
-
-#' plot method for DIF
+#' plot method for pairwise DIF statistics
 #' 
-#' @param x object produced by DIF
+#' @param x object produced by \code{\link{DIF}}
 #' @param items character vector of item id's for a subset of the plot. Useful if you have many items. 
 #' If NULL all items are plotted.
 #' @param itemsX character vector of item id's for the X axis
 #' @param itemsY character vector of item id's for the Y axis
+#' @param alpha significance level used to color the plot (two sided)
 #' @param ... further arguments to plot
-#'    
-plot.DIF_stats = function(x, items = NULL, itemsX = items, itemsY = items, ...)
+#' 
+#' @details
+#' Plotting produces an image of the matrix of pairwise DIF statistics. 
+#' The statistics are standard normal deviates and colored to distinguish significant from non-significant values.
+#' If there is no DIF, a proportion alpha will be significant be change.
+#'      
+plot.DIF_stats = function(x, items = NULL, itemsX = items, itemsY = items, alpha =.05,...)
 {
   if(is.null(itemsX)) itemsX = sort(unique(x$items$item_id))
   if(is.null(itemsY)) itemsY = sort(unique(x$items$item_id))
@@ -167,7 +175,7 @@ plot.DIF_stats = function(x, items = NULL, itemsX = items, itemsY = items, ...)
     inner_join(tibble(item_id = itemsY, ord = 1:length(itemsY)), by='item_id') %>%
     arrange(.data$ord)
   
-  DIF_pair = x$DIF_pair[itemsX$rn, itemsY$rn]
+  DIF_pair = abs(x$DIF_pair[itemsX$rn, itemsY$rn])
   
   
   if(nrow(distinct(x$items,.data$item_id)) == nrow(x$items))
@@ -181,44 +189,59 @@ plot.DIF_stats = function(x, items = NULL, itemsX = items, itemsY = items, ...)
     
   }
   
-  min_ = min(x$DIF_pair) # keep color range from complete object
   max_ = max(x$DIF_pair)
   default.args = list(main = paste(x$group_labels[1],'vs.',x$group_labels[2]),
-                      axes=FALSE, zlim=c(min_,max_),xlab='',ylab='')
+                      axes=FALSE, zlim=c(0,max_),xlab='',ylab='',useRaster=TRUE)
   
-  graphics::layout(matrix(data=c(1,2), nrow=1, ncol=2), widths=c(4,1), heights=c(1,1))
+  oldpar = par(no.readonly = TRUE)
+  on.exit({par(oldpar)},add=TRUE)
   
+  graphics::layout(matrix(data=c(1,2), nrow=1, ncol=2), widths=c(9,2), heights=c(1,1))
   
-  tmp = rainbow(256)[1:128]
-  ColorRamp=c(tmp, tmp[128:1])
-  ColorLevels <- seq(min(x$DIF_pair), max(x$DIF_pair), length=length(ColorRamp))
+  qn = qnorm(1-alpha/2)
+  
+  breaks = seq(0, qn, .05)
+  col = colorRampPalette(c('white','lightblue'))(length(breaks)-1)
+  if(max_ > qn)
+  {
+    breaks_b = seq(qn, min(20,max_), .05)
+    breaks_b[length(breaks_b)] = max_ + 21
+    col = c(col,colorRampPalette(c('gold1','red2'))(length(breaks_b)))
+    breaks = c(breaks, breaks_b)
+  }
   
   # Reverse Y axis
   # yLabels <- rev(yLabels)
-   xLabels <- rev(xLabels)
-   DIF_pair <- DIF_pair[nrow(DIF_pair) : 1,]
+  xLabels <- rev(xLabels)
+  DIF_pair <- DIF_pair[nrow(DIF_pair) : 1,]
   
   # Data Map
-  oldpar = par(mar = c(6,8,2.5,2))
-  on.exit({par(oldpar)},add=TRUE)
+  par(mar = c(6,8,2.5,2))
+  
+  
   do.call(image,
           merge_arglists(list(...),
                          override = list(x = 1:length(yLabels), y = 1:length(xLabels), z=t( DIF_pair),
-                                         col=ColorRamp),
+                                         col=col,breaks=breaks),
                          default = default.args))
   
   
-  axis(1, at=1:length(yLabels), labels=yLabels, las= 3, cex.axis=0.6, hadj=1,padj=0.5)
+  axis(1, at=1:length(yLabels), labels=yLabels, las=3, cex.axis=0.6, hadj=1,padj=0.5)
   axis(2, at=1:length(xLabels), labels=xLabels, las=1, cex.axis=0.6, hadj=1,padj=0.5)
   
   #Color Scale
-  par(mar=c(6,3,2,2))
-  image(1, ColorLevels,
-        matrix(data=ColorLevels, ncol=length(ColorLevels),nrow=1),
-        col=ColorRamp,
-        xlab="",ylab="",
-        xaxt="n")
+  try({
+    par(mar=c(6,2.5,2,2))
+    image(1, seq(0, max(qn,min(20,max_)), by=.05),
+          matrix(seq(0, max(qn,min(20,max_)), by=.05),nrow=1),
+          col=col,
+          breaks=breaks,
+          xlab="",ylab="",
+          xaxt="n", axes=FALSE)
+    axis(2, at=0:min(20,max_),lwd=0,lwd.ticks=1,las=2)
+    graphics::layout(1)
+  }, silent=TRUE)
   
-  graphics::layout(1)
-
-}
\ No newline at end of file
+  
+  invisible(NULL)
+}
