@@ -1,7 +1,6 @@
 context('test database')
 
 library(dplyr)
-library(tibble)
 library(DBI)
 library(RSQLite)
 
@@ -26,6 +25,7 @@ verbAggCopy = function(pth = '../verbAggression.db')
 
 test_that('rule updates and sanity checks',
 {
+  skip_on_os('solaris')
   db = verbAggCopy()
   
   rules = get_rules(db)
@@ -107,13 +107,14 @@ test_that('rule updates and sanity checks',
 
 test_that('adding person and item properties',
 {
+  skip_on_os('solaris')
   # items
   db = verbAggCopy()
   
   expect_error({add_item_properties(db,tibble(a=1,b=2))},'item_id')
   
   # item id "1" does not exist
-  expect_output({add_item_properties(db,tibble(Item_id=1,b=2))}, '0 items')
+  expect_output({add_item_properties(db,tibble(item_id=1,b=2))}, '0 items')
   
   expect_output({add_item_properties(db,tibble(item_id='S4DoCurse', BlAme='society', news='olds'))},
                 '2 item properties? for 1 items? added or updated', perl=TRUE)
